==> haskell-hslua-module-version-1.1.1-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-version
version:              1.1.1
visibility:           public
id:                   hslua-module-version-1.1.1-EivQE2jG3uUKPVHatf6Uoa
key:                  hslua-module-version-1.1.1-EivQE2jG3uUKPVHatf6Uoa
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  9b92e7793f75125a3a01e2f6cc0e813a
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.1-EivQE2jG3uUKPVHatf6Uoa
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.1-DjZmSmXfxQbKBSEvMP0km8
    hslua-marshalling-2.3.1-gPdOtHZ85Q5cVAj29blmQ
    hslua-packaging-2.3.1-7ow6D3tutuCHtMJdugwL3J text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-version-1.1.1-83-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-version
version:              1.1.1
visibility:           public
id:                   hslua-module-version-1.1.1-5Zx8C01PybIEuecr5TTffI
key:                  hslua-module-version-1.1.1-5Zx8C01PybIEuecr5TTffI
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  043cb4f3ab4f2a882169bb91a60a7756
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.1-5Zx8C01PybIEuecr5TTffI
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.1-7yjTwhq4ZVWnQI6hPPir7
    hslua-marshalling-2.3.1-BUpAEeJ9M1GByaGxhbCbLe
    hslua-packaging-2.3.1-6Kjqdq7IbGpisY9cjFouR text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
